@@ -52,11 +52,12 @@ class ObjectTool(object):
         """
         Collects admin and form media.
         """
-        js = ['js/core.js', 'js/admin/RelatedObjectLookups.js',
-              'js/jquery.min.js', 'js/jquery.init.js']
+        js = ['admin/js/core.js', 'admin/js/admin/RelatedObjectLookups.js',
+              'admin/js/jquery.min.js', 'admin/js/jquery.init.js']
 
-        media = forms.Media(js=['%s%s' % (settings.ADMIN_MEDIA_PREFIX, url) \
-                for url in js])
+        media = forms.Media(
+            js=['%s%s' % (settings.STATIC_URL, url) for url in js],
+        )
 
         if form:
             for name, field in form.fields.iteritems():
